==> jc-1.4.0.tar.gz: soot/jimple/internal/AbstractIntLongBinopExpr.h <==
// public abstract class soot.jimple.internal.AbstractIntLongBinopExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d9b18ba3bd644eaa soot_jimple_internal_AbstractBinopExpr
// @dep_class 91b80fdb10e99b48 soot_jimple_internal_AbstractIntLongBinopExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractBinopExpr

#include "soot/jimple/internal/AbstractBinopExpr.h"

#ifndef _JC_soot_jimple_internal_AbstractIntLongBinopExpr_H_
#define _JC_soot_jimple_internal_AbstractIntLongBinopExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Type$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_AbstractIntLongBinopExpr$sub_refs	_jc_soot_jimple_internal_AbstractIntLongBinopExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_AbstractIntLongBinopExpr$sub_nonrefs	_jc_soot_jimple_internal_AbstractIntLongBinopExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_AbstractIntLongBinopExpr$refs	_jc_soot_jimple_internal_AbstractIntLongBinopExpr$refs;
typedef struct _jc_soot_jimple_internal_AbstractIntLongBinopExpr$nonrefs	_jc_soot_jimple_internal_AbstractIntLongBinopExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_AbstractIntLongBinopExpr$object	_jc_soot_jimple_internal_AbstractIntLongBinopExpr$object;

typedef const struct _jc_soot_jimple_internal_AbstractIntLongBinopExpr$vmethods	_jc_soot_jimple_internal_AbstractIntLongBinopExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_AbstractIntLongBinopExpr$vtable	_jc_soot_jimple_internal_AbstractIntLongBinopExpr$vtable;
typedef const struct _jc_soot_jimple_internal_AbstractIntLongBinopExpr$vtype	_jc_soot_jimple_internal_AbstractIntLongBinopExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_AbstractIntLongBinopExpr$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_internal_AbstractIntLongBinopExpr$object *);

// Virtual methods
extern struct _jc_soot_Type$object *_jc_soot_jimple_internal_AbstractIntLongBinopExpr$method$getType$847707b1f3b96fef(_jc_env *, struct _jc_soot_jimple_internal_AbstractIntLongBinopExpr$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_AbstractIntLongBinopExpr$method_info$getType$847707b1f3b96fef;

// Virtual methods structure
struct _jc_soot_jimple_internal_AbstractIntLongBinopExpr$vmethods {
	struct _jc_soot_Type$object	*(*getType$847707b1f3b96fef)(_jc_env *, struct _jc_soot_jimple_internal_AbstractIntLongBinopExpr$object *);
};

// Vtable
struct _jc_soot_jimple_internal_AbstractIntLongBinopExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractBinopExpr$vmethods	soot_jimple_internal_AbstractBinopExpr;
	_jc_soot_jimple_internal_AbstractIntLongBinopExpr$vmethods	soot_jimple_internal_AbstractIntLongBinopExpr;
};

// Vtype
struct _jc_soot_jimple_internal_AbstractIntLongBinopExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_AbstractIntLongBinopExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_AbstractIntLongBinopExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_AbstractIntLongBinopExpr$refs {
    _jc_soot_jimple_internal_AbstractIntLongBinopExpr$sub_refs	soot_jimple_internal_AbstractIntLongBinopExpr;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_refs	soot_jimple_internal_AbstractBinopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_AbstractIntLongBinopExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_AbstractIntLongBinopExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractBinopExpr;
    _jc_soot_jimple_internal_AbstractIntLongBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractIntLongBinopExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_AbstractIntLongBinopExpr$object {
	_jc_soot_jimple_internal_AbstractIntLongBinopExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_AbstractIntLongBinopExpr$vtype	*vtype;
	_jc_soot_jimple_internal_AbstractIntLongBinopExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_AbstractIntLongBinopExpr$vtype _jc_soot_jimple_internal_AbstractIntLongBinopExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_AbstractIntLongBinopExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_AbstractIntLongBinopExpr$class_object;

#endif	/* _JC_soot_jimple_internal_AbstractIntLongBinopExpr_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/internal/AbstractIntLongBinopExpr.h <==
// public abstract class soot.jimple.internal.AbstractIntLongBinopExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d9b18ba3bd644eaa soot_jimple_internal_AbstractBinopExpr
// @dep_class 91b80fdb10e99b48 soot_jimple_internal_AbstractIntLongBinopExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractBinopExpr

#include "soot/jimple/internal/AbstractBinopExpr.h"

#ifndef _JC_soot_jimple_internal_AbstractIntLongBinopExpr_H_
#define _JC_soot_jimple_internal_AbstractIntLongBinopExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Type$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_AbstractIntLongBinopExpr$sub_refs	_jc_soot_jimple_internal_AbstractIntLongBinopExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_AbstractIntLongBinopExpr$sub_nonrefs	_jc_soot_jimple_internal_AbstractIntLongBinopExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_AbstractIntLongBinopExpr$refs	_jc_soot_jimple_internal_AbstractIntLongBinopExpr$refs;
typedef struct _jc_soot_jimple_internal_AbstractIntLongBinopExpr$nonrefs	_jc_soot_jimple_internal_AbstractIntLongBinopExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_AbstractIntLongBinopExpr$object	_jc_soot_jimple_internal_AbstractIntLongBinopExpr$object;

typedef const struct _jc_soot_jimple_internal_AbstractIntLongBinopExpr$vmethods	_jc_soot_jimple_internal_AbstractIntLongBinopExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_AbstractIntLongBinopExpr$vtable	_jc_soot_jimple_internal_AbstractIntLongBinopExpr$vtable;
typedef const struct _jc_soot_jimple_internal_AbstractIntLongBinopExpr$vtype	_jc_soot_jimple_internal_AbstractIntLongBinopExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_AbstractIntLongBinopExpr$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_internal_AbstractIntLongBinopExpr$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_soot_Type$object *_jc_soot_jimple_internal_AbstractIntLongBinopExpr$method$getType$847707b1f3b96fef(_jc_env *, struct _jc_soot_jimple_internal_AbstractIntLongBinopExpr$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_AbstractIntLongBinopExpr$method_info$getType$847707b1f3b96fef;

// Virtual methods structure
struct _jc_soot_jimple_internal_AbstractIntLongBinopExpr$vmethods {
	struct _jc_soot_Type$object	*(*getType$847707b1f3b96fef)(_jc_env *, struct _jc_soot_jimple_internal_AbstractIntLongBinopExpr$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_internal_AbstractIntLongBinopExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractBinopExpr$vmethods	soot_jimple_internal_AbstractBinopExpr;
	_jc_soot_jimple_internal_AbstractIntLongBinopExpr$vmethods	soot_jimple_internal_AbstractIntLongBinopExpr;
};

// Vtype
struct _jc_soot_jimple_internal_AbstractIntLongBinopExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_AbstractIntLongBinopExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_AbstractIntLongBinopExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_AbstractIntLongBinopExpr$refs {
    _jc_soot_jimple_internal_AbstractIntLongBinopExpr$sub_refs	soot_jimple_internal_AbstractIntLongBinopExpr;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_refs	soot_jimple_internal_AbstractBinopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_AbstractIntLongBinopExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_AbstractIntLongBinopExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractBinopExpr;
    _jc_soot_jimple_internal_AbstractIntLongBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractIntLongBinopExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_AbstractIntLongBinopExpr$object {
	_jc_soot_jimple_internal_AbstractIntLongBinopExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_AbstractIntLongBinopExpr$vtype	*vtype;
	_jc_soot_jimple_internal_AbstractIntLongBinopExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_AbstractIntLongBinopExpr$vtype _jc_soot_jimple_internal_AbstractIntLongBinopExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_AbstractIntLongBinopExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_AbstractIntLongBinopExpr$class_object;

#endif	/* _JC_soot_jimple_internal_AbstractIntLongBinopExpr_H_ */
